@@ -1,7 +1,7 @@
 from odin import OdinClient
 from exceptions import APIException
 
-client = OdinClient("https://api.getodin.com/v1", "<APIKey>")
+client = OdinClient("https://api.getodin.com/v1", "OoxT7edjgNbnmp+Iiap4qropxuAZ37paJmhvTvdAtsw=")
 
 def ex_hosts_count():
     # Example for using get_hosts_count
@@ -118,11 +118,11 @@ def ex_certificates_summary():
         print(e.message)
 
 if __name__ == "__main__":
-    ex_hosts_count()
+    # ex_hosts_count()
     # ex_certificate_count()
     # ex_certificate_hash_details()
     # ex_certificates_summary()
-    # ex_search_certificates()
+    ex_search_certificates()
     # ex_search_hosts()
     # ex_hosts_cve_details()
     # ex_hosts_ip_details()
\ No newline at end of file
